@@ -17,18 +17,28 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 # USA.
 
-from .devices import Camera, DeviceFactory, Motion, Router, Siren, Sound, Water
-from .soapclient import AuthenticationError, MethodCallError
-
+from .devices import (
+    Camera,
+    Device,
+    DeviceFactory,
+    Motion,
+    Router,
+    Siren,
+    SirenSound,
+    Water,
+)
+from .soapclient import AuthenticationError, MethodCallError, SoapClient
 
 __all__ = [
     "AuthenticationError",
     "MethodCallError",
+    "Device",
     "DeviceFactory",
     "Camera",
     "Motion",
     "Router",
     "Siren",
-    "Sound",
+    "SirenSound",
+    "SoapClient",
     "Water",
 ]
